pub struct PciDeviceStructureGeneralDevice {Show 14 fields
pub common_header: PciDeviceStructureHeader,
pub standard_device_bar: PciStandardDeviceBar,
pub cardbus_cis_pointer: u32,
pub subsystem_vendor_id: u16,
pub subsystem_id: u16,
pub expansion_rom_base_address: u32,
pub capabilities_pointer: u8,
pub reserved0: u8,
pub reserved1: u16,
pub reserved2: u32,
pub interrupt_line: u8,
pub interrupt_pin: u8,
pub min_grant: u8,
pub max_latency: u8,
}Expand description
Pci_Device_Structure_General_Device PCI标准设备结构体
Fields
common_header: PciDeviceStructureHeaderstandard_device_bar: PciStandardDeviceBarcardbus_cis_pointer: u32subsystem_vendor_id: u16subsystem_id: u16expansion_rom_base_address: u32capabilities_pointer: u8reserved0: u8reserved1: u16reserved2: u32interrupt_line: u8interrupt_pin: u8min_grant: u8max_latency: u8Trait Implementations
Sourceimpl Clone for PciDeviceStructureGeneralDevice
impl Clone for PciDeviceStructureGeneralDevice
Sourcefn clone(&self) -> PciDeviceStructureGeneralDevice
fn clone(&self) -> PciDeviceStructureGeneralDevice
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PciDeviceStructure for PciDeviceStructureGeneralDevice
impl PciDeviceStructure for PciDeviceStructureGeneralDevice
Sourcefn header_type(&self) -> HeaderType
fn header_type(&self) -> HeaderType
Get the type of the device structure.
Sourcefn as_standard_device(&self) -> Option<&PciDeviceStructureGeneralDevice>
fn as_standard_device(&self) -> Option<&PciDeviceStructureGeneralDevice>
This function returns a
PciDeviceStructureGeneralDevice if the device structure is a standard device, and None otherwise.Sourcefn as_standard_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructureGeneralDevice>
fn as_standard_device_mut( &mut self, ) -> Option<&mut PciDeviceStructureGeneralDevice>
Return a mutable reference to the PciDeviceStructureGeneralDevice if the device structure is a standard device, and
None otherwise.Sourcefn common_header(&self) -> &PciDeviceStructureHeader
fn common_header(&self) -> &PciDeviceStructureHeader
Return a immutable reference to the common header.
Sourcefn common_header_mut(&mut self) -> &mut PciDeviceStructureHeader
fn common_header_mut(&mut self) -> &mut PciDeviceStructureHeader
Returns the mutable reference to the common header.
Sourcefn capabilities(&self) -> Option<CapabilityIterator>
fn capabilities(&self) -> Option<CapabilityIterator>
Returns the iterator of the Capabilities.
Sourcefn bar_init(&mut self) -> Option<Result<u8, PciError>>
fn bar_init(&mut self) -> Option<Result<u8, PciError>>
@brief 读取standard设备的bar寄存器,映射后将结果加入结构体的standard_device_bar变量
@return 只有standard设备才返回成功或者错误,其余返回None
Sourcefn as_pci_to_pci_bridge_device(
&self,
) -> Option<&PciDeviceStructurePciToPciBridge>
fn as_pci_to_pci_bridge_device( &self, ) -> Option<&PciDeviceStructurePciToPciBridge>
This function returns a
PciDeviceStructurePciToPciBridge if the device structure is a pci to pci bridge, and None otherwise.Sourcefn as_pci_to_carbus_bridge_device(
&self,
) -> Option<&PciDeviceStructurePciToCardbusBridge>
fn as_pci_to_carbus_bridge_device( &self, ) -> Option<&PciDeviceStructurePciToCardbusBridge>
This function returns a
PciDeviceStructurePciToCardbusBridge if the device structure is a pci to cardbus bridge, and None otherwise.Sourcefn as_pci_to_pci_bridge_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructurePciToPciBridge>
fn as_pci_to_pci_bridge_device_mut( &mut self, ) -> Option<&mut PciDeviceStructurePciToPciBridge>
Return a mutable reference to the PciDeviceStructurePciToPciBridge if the device structure is a pci to pci bridge, and
None otherwise.Sourcefn as_pci_to_carbus_bridge_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructurePciToCardbusBridge>
fn as_pci_to_carbus_bridge_device_mut( &mut self, ) -> Option<&mut PciDeviceStructurePciToCardbusBridge>
Return a mutable reference to the PciDeviceStructurePciToCardbusBridge if the device structure is a pci to cardbus bridge, and
None otherwise.Sourcefn status_command(&self) -> (Status, Command)
fn status_command(&self) -> (Status, Command)
Gets the values of the Status and Command registers.
Sourcefn set_command(&mut self, command: Command)
fn set_command(&mut self, command: Command)
Set the value of the Command register.
fn enable_master(&mut self)