pub struct PciDeviceStructurePciToCardbusBridge {Show 23 fields
pub common_header: PciDeviceStructureHeader,
pub cardbus_socket_ex_ca_base_address: u32,
pub offset_of_capabilities_list: u8,
pub reserved: u8,
pub secondary_status: u16,
pub pci_bus_number: u8,
pub card_bus_bus_number: u8,
pub subordinate_bus_number: u8,
pub card_bus_latency_timer: u8,
pub memory_base_address0: u32,
pub memory_limit0: u32,
pub memory_base_address1: u32,
pub memory_limit1: u32,
pub io_base_address0: u32,
pub io_limit0: u32,
pub io_base_address1: u32,
pub io_limit1: u32,
pub interrupt_line: u8,
pub interrupt_pin: u8,
pub bridge_control: u16,
pub subsystem_device_id: u16,
pub subsystem_vendor_id: u16,
pub pc_card_legacy_mode_base_address_16_bit: u32,
}Expand description
Pci_Device_Structure_Pci_to_Cardbus_Bridge Pci_to_Cardbus桥设备结构体
Fields
common_header: PciDeviceStructureHeadercardbus_socket_ex_ca_base_address: u32offset_of_capabilities_list: u8reserved: u8secondary_status: u16pci_bus_number: u8card_bus_bus_number: u8subordinate_bus_number: u8card_bus_latency_timer: u8memory_base_address0: u32memory_limit0: u32memory_base_address1: u32memory_limit1: u32io_base_address0: u32io_limit0: u32io_base_address1: u32io_limit1: u32interrupt_line: u8interrupt_pin: u8bridge_control: u16subsystem_device_id: u16subsystem_vendor_id: u16pc_card_legacy_mode_base_address_16_bit: u32Trait Implementations
Sourceimpl Clone for PciDeviceStructurePciToCardbusBridge
impl Clone for PciDeviceStructurePciToCardbusBridge
Sourcefn clone(&self) -> PciDeviceStructurePciToCardbusBridge
fn clone(&self) -> PciDeviceStructurePciToCardbusBridge
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PciDeviceStructure for PciDeviceStructurePciToCardbusBridge
impl PciDeviceStructure for PciDeviceStructurePciToCardbusBridge
Sourcefn header_type(&self) -> HeaderType
fn header_type(&self) -> HeaderType
Get the type of the device structure.
Sourcefn as_pci_to_carbus_bridge_device(
&self,
) -> Option<&PciDeviceStructurePciToCardbusBridge>
fn as_pci_to_carbus_bridge_device( &self, ) -> Option<&PciDeviceStructurePciToCardbusBridge>
This function returns a
PciDeviceStructurePciToCardbusBridge if the device structure is a pci to cardbus bridge, and None otherwise.Sourcefn as_pci_to_carbus_bridge_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructurePciToCardbusBridge>
fn as_pci_to_carbus_bridge_device_mut( &mut self, ) -> Option<&mut PciDeviceStructurePciToCardbusBridge>
Return a mutable reference to the PciDeviceStructurePciToCardbusBridge if the device structure is a pci to cardbus bridge, and
None otherwise.Sourcefn common_header(&self) -> &PciDeviceStructureHeader
fn common_header(&self) -> &PciDeviceStructureHeader
Return a immutable reference to the common header.
Sourcefn common_header_mut(&mut self) -> &mut PciDeviceStructureHeader
fn common_header_mut(&mut self) -> &mut PciDeviceStructureHeader
Returns the mutable reference to the common header.
Sourcefn as_standard_device(&self) -> Option<&PciDeviceStructureGeneralDevice>
fn as_standard_device(&self) -> Option<&PciDeviceStructureGeneralDevice>
This function returns a
PciDeviceStructureGeneralDevice if the device structure is a standard device, and None otherwise.Sourcefn as_pci_to_pci_bridge_device(
&self,
) -> Option<&PciDeviceStructurePciToPciBridge>
fn as_pci_to_pci_bridge_device( &self, ) -> Option<&PciDeviceStructurePciToPciBridge>
This function returns a
PciDeviceStructurePciToPciBridge if the device structure is a pci to pci bridge, and None otherwise.Sourcefn as_standard_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructureGeneralDevice>
fn as_standard_device_mut( &mut self, ) -> Option<&mut PciDeviceStructureGeneralDevice>
Return a mutable reference to the PciDeviceStructureGeneralDevice if the device structure is a standard device, and
None otherwise.Sourcefn as_pci_to_pci_bridge_device_mut(
&mut self,
) -> Option<&mut PciDeviceStructurePciToPciBridge>
fn as_pci_to_pci_bridge_device_mut( &mut self, ) -> Option<&mut PciDeviceStructurePciToPciBridge>
Return a mutable reference to the PciDeviceStructurePciToPciBridge if the device structure is a pci to pci bridge, and
None otherwise.Sourcefn capabilities(&self) -> Option<CapabilityIterator>
fn capabilities(&self) -> Option<CapabilityIterator>
Returns the iterator of the Capabilities.
Sourcefn status_command(&self) -> (Status, Command)
fn status_command(&self) -> (Status, Command)
Gets the values of the Status and Command registers.
Sourcefn set_command(&mut self, command: Command)
fn set_command(&mut self, command: Command)
Set the value of the Command register.
Sourcefn bar_init(&mut self) -> Option<Result<u8, PciError>>
fn bar_init(&mut self) -> Option<Result<u8, PciError>>
@brief 读取standard设备的bar寄存器,映射后将结果加入结构体的standard_device_bar变量
@return 只有standard设备才返回成功或者错误,其余返回None
fn enable_master(&mut self)