Struct Status

pub struct Status(/* private fields */);
The status register in PCI configuration space.

Implementations

Source

impl Status

pub const INTERRUPT_STATUS: Self

The state of the device’s INTx# signal.

pub const CAPABILITIES_LIST: Self

The device has a linked list of capabilities.

pub const MHZ_66_CAPABLE: Self

The device is capabile of running at 66 MHz rather than 33 MHz.

pub const FAST_BACK_TO_BACK_CAPABLE: Self

The device can accept fast back-to-back transactions not from the same agent.

pub const MASTER_DATA_PARITY_ERROR: Self

The bus agent observed a parity error (if parity error handling is enabled).

pub const SIGNALED_TARGET_ABORT: Self

A target device terminated a transaction with target-abort.

pub const RECEIVED_TARGET_ABORT: Self

A master device transaction was terminated with target-abort.

pub const RECEIVED_MASTER_ABORT: Self

A master device transaction was terminated with master-abort.

pub const SIGNALED_SYSTEM_ERROR: Self

A device asserts SERR#.

pub const DETECTED_PARITY_ERROR: Self

The device detects a parity error, even if parity error handling is disabled.

Source

impl Status

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Status

pub const fn iter(&self) -> Iter<Status>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Status>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.