macro_rules! serial_println {
() => { ... };
($($arg: tt)*) => { ... };
}Expand description
Print something to the serial port, appending a newline.
macro_rules! serial_println {
() => { ... };
($($arg: tt)*) => { ... };
}Print something to the serial port, appending a newline.