pub struct SignalManager { /* private fields */ }Expand description
The signal manager. You don’t need to create one by yourself.
Implementations
Sourceimpl SignalManager
impl SignalManager
pub fn new(signal_type_num: usize) -> Self
Sourcepub fn has_signal(&self, signal_type: usize) -> bool
pub fn has_signal(&self, signal_type: usize) -> bool
Returns whether the signal type is registered.
Sourcepub fn register_signal(&mut self, signal_type: usize, signal: Signal) -> bool
pub fn register_signal(&mut self, signal_type: usize, signal: Signal) -> bool
Registers a new signal and wakes up the process if it is waiting for the signal.
Sourcepub fn register_wait_for(&mut self, signal_type: usize)
pub fn register_wait_for(&mut self, signal_type: usize)
Starts to wait for a signal.
Sourcepub fn get_signal(&mut self, signal_type: usize) -> Option<Signal>
pub fn get_signal(&mut self, signal_type: usize) -> Option<Signal>
Gets a signal of the specified type. Returns None if the signal type is not registered.
Sourcepub fn delete_signal(&mut self, signal_type: usize)
pub fn delete_signal(&mut self, signal_type: usize)
Deletes a signal of the specified type. Nothing happens if the signal type is not registered.